@@ -72,6 +72,8 @@ int main(int, char**)
             << get_defs(G_TYPE_LOADABLE_ICON)
             << get_defs(G_TYPE_MEMORY_INPUT_STREAM)
             << get_defs(G_TYPE_MEMORY_OUTPUT_STREAM)
+            << get_defs(G_TYPE_MENU)
+            << get_defs(G_TYPE_MENU_MODEL)
             << get_defs(G_TYPE_MOUNT)
             << get_defs(G_TYPE_MOUNT_OPERATION)
             << get_defs(G_TYPE_PROXY)
@@ -119,10 +121,12 @@ int main(int, char**)
             << get_defs(G_TYPE_DBUS_ERROR)
             << get_defs(G_TYPE_DBUS_ANNOTATION_INFO)
             << get_defs(G_TYPE_DBUS_ARG_INFO)
+            << get_defs(G_TYPE_DBUS_MENU_MODEL)
             << get_defs(G_TYPE_DBUS_METHOD_INFO)
             << get_defs(G_TYPE_DBUS_SIGNAL_INFO)
             << get_defs(G_TYPE_DBUS_PROPERTY_INFO)
             << get_defs(G_TYPE_DBUS_INTERFACE_INFO)
+            << get_defs(G_TYPE_DBUS_OBJECT)
             << get_defs(G_TYPE_DBUS_NODE_INFO)
             << get_defs(G_TYPE_DBUS_MESSAGE)
             << get_defs(G_TYPE_DBUS_METHOD_INVOCATION)
